@@ -11,6 +11,7 @@ bic.mixcompnorm <- function(x, G, type = "alr", veo = FALSE, graph = TRUE) {
   ## A is the maximum number of components to be considered
   ## type is either 'alr' or 'ilr'
   p <- dim(x)[2]  ## dimensionality of the data
+  
   if ( type == "alr" ) {
     y <- log(x[, -1] / x[, 1])
   } else if (type == "ilr") {
@@ -27,8 +28,9 @@ bic.mixcompnorm <- function(x, G, type = "alr", veo = FALSE, graph = TRUE) {
   if ( graph ) {
     plot( G, mbic[, 1], type = "b", pch = 9, xlab = "Number of components",
     ylab = "BIC values", ylim = c( min(mbic, na.rm = TRUE), max(mbic, na.rm = TRUE) ),
-    cex.lab = 1.3, )
+    cex.lab = 1.2, cex.axis = 1.2)
     for ( i in 2:ncol(mbic) )  lines(G, mbic[, i], type = "b", pch = 9, col = i)
   }
+  
   list(mod = mod, BIC = mbic)
 }
