@@ -29,7 +29,7 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
   namx <- colnames(x)
   namy <- colnames(y)
   if ( is.null( namy ) )  {
-    namy <- paste("Y", 1:d, sep = "")
+    namy <- paste("Y", 2:(d + 1), sep = "")
   } else namy <- namy[-1]
 
   ## the next lines minimize the kl.compreg function and obtain the estimated betas
@@ -80,6 +80,7 @@ js.compreg <- function(y, x, B = 1, ncores = 1, xnew = NULL) {
       covb <- cov(betaboot)
       runtime <- proc.time() - runtime
     }  ##  end (nc <= 1) {
+	
     nam <- NULL
     for (i in 1:p)  nam <- c(nam, paste(namy, ":", namx[i], sep = "") )
     colnames(covb) <- rownames(covb) <- nam
